@@ -1,37 +1,23 @@
 /*
-    Copyright (C) 2010 Klarälvdalens Datakonsult AB,
-        a KDAB Group company, info@kdab.net,
-        author Stephen Kelly <stephen@kdab.com>
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+    SPDX-FileContributor: Stephen Kelly <stephen@kdab.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "modeleventlogger.h"
-#include "modeldumper.h"
 #include "indexfinder.h"
+#include "modeldumper.h"
 
 #include "eventloggerregister.h"
 
-#include <QStringList>
-#include <QFile>
 #include <QDebug>
+#include <QFile>
+#include <QStringList>
 
 #ifdef Grantlee_FOUND
-#include <grantlee_core.h>
 #include "grantlee_paths.h"
+#include <grantlee_core.h>
 
 /**
   Don't escape the code generation output.
@@ -44,16 +30,14 @@ public:
     NoEscapeOutputStream()
         : Grantlee::OutputStream()
     {
-
     }
 
     NoEscapeOutputStream(QTextStream *stream)
         : OutputStream(stream)
     {
-
     }
 
-    virtual QSharedPointer< Grantlee::OutputStream > clone() const
+    virtual QSharedPointer<Grantlee::OutputStream> clone() const
     {
         return QSharedPointer<Grantlee::OutputStream>(new NoEscapeOutputStream);
     }
@@ -68,10 +52,9 @@ public:
 class ModelWrapper : public QAbstractItemModel
 {
 public:
-    ModelWrapper(QAbstractItemModel */*model*/, QObject *parent = nullptr)
+    ModelWrapper(QAbstractItemModel * /*model*/, QObject *parent = nullptr)
         : QAbstractItemModel(parent)
     {
-
     }
 
     QModelIndexList per() const
@@ -79,23 +62,23 @@ public:
         return persistentIndexList();
     }
 
-    QModelIndex index(int /*row*/, int /*column*/, const QModelIndex & /*parent*/ = QModelIndex()) const Q_DECL_OVERRIDE
+    QModelIndex index(int /*row*/, int /*column*/, const QModelIndex & /*parent*/ = QModelIndex()) const override
     {
         return QModelIndex();
     }
-    int rowCount(const QModelIndex & /*parent*/ = QModelIndex()) const Q_DECL_OVERRIDE
+    int rowCount(const QModelIndex & /*parent*/ = QModelIndex()) const override
     {
         return 0;
     }
-    QModelIndex parent(const QModelIndex & /*child*/) const Q_DECL_OVERRIDE
+    QModelIndex parent(const QModelIndex & /*child*/) const override
     {
         return QModelIndex();
     }
-    int columnCount(const QModelIndex & /*parent*/ = QModelIndex()) const Q_DECL_OVERRIDE
+    int columnCount(const QModelIndex & /*parent*/ = QModelIndex()) const override
     {
         return 0;
     }
-    QVariant data(const QModelIndex & /*index*/, int /*role*/ = Qt::DisplayRole) const Q_DECL_OVERRIDE
+    QVariant data(const QModelIndex & /*index*/, int /*role*/ = Qt::DisplayRole) const override
     {
         return QVariant();
     }
@@ -104,17 +87,9 @@ public:
 ModelEvent::ModelEvent(QObject *parent)
     : QObject(parent)
 {
-
 }
 
-static const char *const sTypes[] = {
-    "Init",
-    "RowsInserted",
-    "RowsRemoved",
-    "DataChanged",
-    "LayoutChanged",
-    "ModelReset"
-};
+static const char *const sTypes[] = {"Init", "RowsInserted", "RowsRemoved", "DataChanged", "LayoutChanged", "ModelReset"};
 
 QString ModelEvent::type() const
 {
@@ -155,7 +130,7 @@ QString ModelEvent::rowAncestors() const
 {
     QString result(QStringLiteral("QList<int>()"));
 
-    Q_FOREACH (const int row, m_rowAncestors) {
+    for (const int row : std::as_const(m_rowAncestors)) {
         result.append(" << ");
         result.append(QString::number(row));
     }
@@ -167,7 +142,7 @@ QString ModelEvent::rowAncestors() const
 //   return m_rowAncestors;
 // }
 
-void ModelEvent::setRowAncestors(QList< int > rowAncestors)
+void ModelEvent::setRowAncestors(QList<int> rowAncestors)
 {
     m_rowAncestors = rowAncestors;
 }
@@ -188,14 +163,17 @@ void ModelEvent::setInterpretString(const QString &interpretString)
 }
 
 ModelEventLogger::ModelEventLogger(QAbstractItemModel *model, QObject *parent)
-    : QObject(parent), m_model(model), m_modelDumper(new ModelDumper), m_numLogs(0)
+    : QObject(parent)
+    , m_model(model)
+    , m_modelDumper(new ModelDumper)
+    , m_numLogs(0)
 {
-    connect(model, SIGNAL(dataChanged(QModelIndex,QModelIndex)), SLOT(dataChanged(QModelIndex,QModelIndex)));
+    connect(model, SIGNAL(dataChanged(QModelIndex, QModelIndex)), SLOT(dataChanged(QModelIndex, QModelIndex)));
     connect(model, SIGNAL(layoutAboutToBeChanged()), SLOT(layoutAboutToBeChanged()));
     connect(model, SIGNAL(layoutChanged()), SLOT(layoutChanged()));
     connect(model, SIGNAL(modelReset()), SLOT(modelReset()));
-    connect(model, SIGNAL(rowsInserted(QModelIndex,int,int)), SLOT(rowsInserted(QModelIndex,int,int)));
-    connect(model, SIGNAL(rowsRemoved(QModelIndex,int,int)), SLOT(rowsRemoved(QModelIndex,int,int)));
+    connect(model, SIGNAL(rowsInserted(QModelIndex, int, int)), SLOT(rowsInserted(QModelIndex, int, int)));
+    connect(model, SIGNAL(rowsRemoved(QModelIndex, int, int)), SLOT(rowsRemoved(QModelIndex, int, int)));
 
     ModelEvent *modelEvent = new ModelEvent(this);
     modelEvent->setType(ModelEvent::Init);
@@ -262,7 +240,7 @@ void ModelEventLogger::dataChanged(const QModelIndex &topLeft, const QModelIndex
     m_events.append(QVariant::fromValue(static_cast<QObject *>(modelEvent)));
 }
 
-void ModelEventLogger::persistChildren(const QModelIndex &/*parent*/)
+void ModelEventLogger::persistChildren(const QModelIndex & /*parent*/)
 {
 }
 
@@ -271,8 +249,8 @@ void ModelEventLogger::layoutAboutToBeChanged()
     m_oldPaths.clear();
     m_persistentIndexes.clear();
     const QModelIndexList list = static_cast<const ModelWrapper *>(m_model)->per();
-    Q_FOREACH (const QPersistentModelIndex &idx, list) {
-        m_persistentIndexes.append(idx);
+    for (const QModelIndex &idx : list) {
+        m_persistentIndexes.append(QPersistentModelIndex(idx));
         m_oldPaths.append(IndexFinder::indexToIndexFinder(idx).rows());
     }
 }
